@@ -5,7 +5,6 @@ import mimetypes
 import os
 import tempfile
 from dataclasses import dataclass
-from typing import ContextManager
 
 import boto3
 from botocore.client import BaseClient
@@ -39,7 +38,7 @@ def s3_make_client(
     secret_access_key: str = None,
     region_name: str = None,
     endpoint_url: str = None,
-) -> ContextManager[BaseClient]:
+) -> contextlib.AbstractContextManager[BaseClient]:
     """
     Makes an AWS S3 client
 
